pub(crate) async fn until<F, A, E>(
t: Duration,
fut: F,
) -> Result<A, NetworkError>Expand description
A variant of timeout that merges the timeout error into network error.
pub(crate) async fn until<F, A, E>(
t: Duration,
fut: F,
) -> Result<A, NetworkError>A variant of timeout that merges the timeout error into network error.